io_utils library
Miscellaneous I/O utilities. This includes for using Pointycastle to
encrypt or decrypt a stream of data, somewhat like
javax.crytpo.CipherInputStream and javax.crypto.CypherOutputStream.
Classes
- DecryptingStream
-
A wrapper around a
DataInputStreamthat decrypts using a PointycastleBlockCipher, resulting in aStream<List<int>>. This is functionally similar tojavax.crypto.CipherInputStream. - EncryptingSink
-
A wrapper around a
Sink<List<int>>that encrypts data using a PointycastleBlockCipher. This sink needs to buffer to build up blocks that can be encrypted, so it's essential that close() be called. This is functionally similar tojavax.crypto.CipherOutputStream